==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_functions/mp0024_001/MP0024_GetWorkOrder_001.java <==

package net.datastream.schemas.mp_functions.mp0024_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYCODE;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="first_activity_only" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       &lt;attribute name="isworkorderquickentry" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="iscontractorportal" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrder" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "activitycode"
})
@XmlRootElement(name = "MP0024_GetWorkOrder_001")
public class MP0024_GetWorkOrder_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "ACTIVITYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYCODE activitycode;
    @XmlAttribute(name = "first_activity_only")
    protected Boolean first_Activity_Only;
    @XmlAttribute(name = "isworkorderquickentry")
    protected Boolean isworkorderquickentry;
    @XmlAttribute(name = "iscontractorportal")
    protected Boolean iscontractorportal;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Obtient la valeur de la propriété activitycode.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Définit la valeur de la propriété activitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Obtient la valeur de la propriété first_Activity_Only.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFirst_Activity_Only() {
        if (first_Activity_Only == null) {
            return true;
        } else {
            return first_Activity_Only;
        }
    }

    /**
     * Définit la valeur de la propriété first_Activity_Only.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFirst_Activity_Only(Boolean value) {
        this.first_Activity_Only = value;
    }

    /**
     * Obtient la valeur de la propriété isworkorderquickentry.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsworkorderquickentry() {
        if (isworkorderquickentry == null) {
            return false;
        } else {
            return isworkorderquickentry;
        }
    }

    /**
     * Définit la valeur de la propriété isworkorderquickentry.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsworkorderquickentry(Boolean value) {
        this.isworkorderquickentry = value;
    }

    /**
     * Obtient la valeur de la propriété iscontractorportal.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIscontractorportal() {
        if (iscontractorportal == null) {
            return false;
        } else {
            return iscontractorportal;
        }
    }

    /**
     * Définit la valeur de la propriété iscontractorportal.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIscontractorportal(Boolean value) {
        this.iscontractorportal = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_functions/mp0024_001/MP0024_GetWorkOrder_001.java <==

package net.datastream.schemas.mp_functions.mp0024_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYCODE;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="first_activity_only" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       &lt;attribute name="isworkorderquickentry" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="iscontractorportal" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrder" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "activitycode"
})
@XmlRootElement(name = "MP0024_GetWorkOrder_001")
public class MP0024_GetWorkOrder_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "ACTIVITYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYCODE activitycode;
    @XmlAttribute(name = "first_activity_only")
    protected Boolean first_Activity_Only;
    @XmlAttribute(name = "isworkorderquickentry")
    protected Boolean isworkorderquickentry;
    @XmlAttribute(name = "iscontractorportal")
    protected Boolean iscontractorportal;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the activitycode property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Sets the value of the activitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Gets the value of the first_Activity_Only property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFirst_Activity_Only() {
        if (first_Activity_Only == null) {
            return true;
        } else {
            return first_Activity_Only;
        }
    }

    /**
     * Sets the value of the first_Activity_Only property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFirst_Activity_Only(Boolean value) {
        this.first_Activity_Only = value;
    }

    /**
     * Gets the value of the isworkorderquickentry property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsworkorderquickentry() {
        if (isworkorderquickentry == null) {
            return false;
        } else {
            return isworkorderquickentry;
        }
    }

    /**
     * Sets the value of the isworkorderquickentry property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsworkorderquickentry(Boolean value) {
        this.isworkorderquickentry = value;
    }

    /**
     * Gets the value of the iscontractorportal property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIscontractorportal() {
        if (iscontractorportal == null) {
            return false;
        } else {
            return iscontractorportal;
        }
    }

    /**
     * Sets the value of the iscontractorportal property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIscontractorportal(Boolean value) {
        this.iscontractorportal = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
